@@ -1,6 +1,5 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
-
+from .intelx import intelx as i
 from time import sleep
 from .colors import colors as c
 import requests
@@ -26,10 +25,10 @@ class local_breach_target:
         self.content = content
 
     def dump(self):
-        print("Email: {}".format(self.target))
-        print("Path: {}".format(self.filepath))
-        print("Line: {}".format(self.line))
-        print("Content: {}".format(self.content))
+        print(f"Email: {self.target}")
+        print(f"Path: {self.filepath}")
+        print(f"Line: {self.line}")
+        print(f"Content: {self.content}")
         print()
 
 
@@ -54,7 +53,7 @@ class target:
         if debug:
             print(
                 c.fg.red,
-                "DEBUG: Created target object for {}".format(self.target),
+                f"DEBUG: Created target object for {self.target}",
                 c.reset,
             )
 
@@ -98,7 +97,7 @@ class target:
                 c.debug_news("DEBUG: RESPONSE HEADER---------------------")
                 print(
                     "\n".join(
-                        "{}: {}".format(k, v) for k, v in response.headers.items()
+                        f"{k}: {v}" for k, v in response.headers.items()
                     )
                 )
                 c.debug_news("DEBUG: RESPONSE BODY---------------------")
@@ -111,105 +110,12 @@ class target:
             print(response)
         return response
 
-    # Deprecated
-    def get_hibp(self):
-        try:
-            sleep(1.3)
-            c.info_news(c.bold + "HIBP free tier will stop working on the 2019/08/18")
-            c.info_news(
-                c.bold
-                + "You can already use a purchased API key using h8mail (config file)"
-                + c.reset
-            )
-            url = "https://haveibeenpwned.com/api/v2/breachedaccount/{}?truncateResponse=true".format(
-                self.target
-            )
-            response = self.make_request(url)
-            if response.status_code not in [200, 404]:
-                c.bad_news("Could not contact HIBP for " + self.target)
-                print(response.status_code)
-                return
-
-            if response.status_code == 200:
-                data = response.json()
-                for d in data:  # Returned type is a dict of Name : Service
-                    for _, ser in d.items():
-                        self.data.append(("HIBP", ser))
-                        self.pwned += 1
-
-                c.good_news(
-                    "Found {num} breaches for {target} using HIBP".format(
-                        num=len(self.data) - 1, target=self.target
-                    )
-                )
-                self.get_hibp_pastes()
-
-            elif response.status_code == 404:
-                c.info_news("No breaches found for {} using HIBP".format(self.target))
-            else:
-                c.bad_news(
-                    "HIBP: got API response code {code} for {target}".format(
-                        code=response.status_code, target=self.target
-                    )
-                )
-        except Exception as ex:
-            c.bad_news("HIBP error: " + self.target)
-            print(ex)
-
-    # Deprecated
-    def get_hibp_pastes(self):
-        try:
-            sleep(1.3)
-            url = "https://haveibeenpwned.com/api/v2/pasteaccount/{}".format(
-                self.target
-            )
-            response = self.make_request(url)
-            if response.status_code not in [200, 404]:
-                c.bad_news("Could not contact HIBP PASTE for " + self.target)
-                print(response.status_code)
-                print(response)
-                return
-
-            if response.status_code == 200:
-
-                data = response.json()
-                for d in data:  # Returned type is a dict of Name : Service
-                    self.pwned += 1
-                    if "Pastebin" in d["Source"]:
-                        self.data.append(
-                            ("HIBP_PASTE", "https://pastebin.com/" + d["Id"])
-                        )
-                    else:
-                        self.data.append(("HIBP_PASTE", d["Id"]))
-
-                c.good_news(
-                    "Found {num} pastes for {target} using HIBP".format(
-                        num=len(data), target=self.target
-                    )
-                )
-
-            elif response.status_code == 404:
-                c.info_news(
-                    "No pastes found for {} using HIBP PASTE".format(self.target)
-                )
-            else:
-                c.bad_news(
-                    "HIBP PASTE: got API response code {code} for {target}".format(
-                        code=response.status_code, target=self.target
-                    )
-                )
-        except Exception as ex:
-            c.bad_news("HIBP PASTE error: " + self.target)
-            print(ex)
-
     # New HIBP API
     def get_hibp3(self, api_key):
         try:
             c.info_news("[" + self.target + "]>[hibp]")
             sleep(1.3)
-            url = "https://haveibeenpwned.com/api/v3/breachedaccount/{}".format(
-                self.target
-            )
+            url = f"https://haveibeenpwned.com/api/v3/breachedaccount/{self.target}"
             self.headers.update({"hibp-api-key": api_key})
             response = self.make_request(url)
             if response.status_code not in [200, 404]:
@@ -233,14 +139,14 @@ class target:
                 self.headers.popitem()
             elif response.status_code == 404:
                 c.info_news(
-                    "No breaches found for {} using HIBP v3".format(self.target)
+                    f"No breaches found for {self.target} using HIBP v3"
                 )
+
             else:
                 c.bad_news(
-                    "HIBP v3: got API response code {code} for {target}".format(
-                        code=response.status_code, target=self.target
-                    )
+                    f"HIBP v3: got API response code {response.status_code} for {self.target}"
                 )
+
         except Exception as e:
             c.bad_news("haveibeenpwned v3: " + self.target)
             print(e)
@@ -250,9 +156,8 @@ class target:
         try:
             c.info_news("[" + self.target + "]>[hibp-paste]")
             sleep(1.3)
-            url = "https://haveibeenpwned.com/api/v3/pasteaccount/{}".format(
-                self.target
-            )
+            url = f"https://haveibeenpwned.com/api/v3/pasteaccount/{self.target}"
+
             response = self.make_request(url)
             if response.status_code not in [200, 404]:
                 c.bad_news("Could not contact HIBP PASTE for " + self.target)
@@ -280,18 +185,97 @@ class target:
 
             elif response.status_code == 404:
                 c.info_news(
-                    "No pastes found for {} using HIBP v3 PASTE".format(self.target)
+                    f"No pastes found for {self.target} using HIBP v3 PASTE"
                 )
             else:
                 c.bad_news(
-                    "HIBP v3 PASTE: got API response code {code} for {target}".format(
-                        code=response.status_code, target=self.target
-                    )
+                    f"HIBP v3 PASTE: got API response code {response.status_code} for {self.target}"
                 )
+
         except Exception as ex:
             c.bad_news("HIBP v3 PASTE error: " + self.target)
             print(ex)
 
+    def get_intelx(self, api_keys):
+        try:
+            intel_files = []
+            intelx = i(key=api_keys["intelx_key"], ua="h8mail-v.{h8ver}-OSINT-and-Education-Tool (PythonVersion={pyver}; Platform={platfrm})".format(
+                h8ver=__version__,
+                pyver=sys.version.split(" ")[0],
+                platfrm=platform.platform().split("-")[0],
+            ))
+            from .intelx_helpers import intelx_getsearch
+            from .localsearch import local_search
+            from os import remove, fspath
+
+            maxfile = 10
+            if api_keys["intelx_maxfile"]:
+                maxfile = int(api_keys["intelx_maxfile"])
+            search = intelx_getsearch(self.target, intelx, maxfile)
+            if self.debug:
+                import json
+
+                print(json.dumps(search, indent=4))
+
+            for record in search["records"]:
+                filename = record["systemid"].strip() + ".txt"
+                intel_files.append(filename)
+                if record["media"] != 24:
+                    c.info_news(
+                        "Skipping {name}, not text ({type})".format(
+                            type=record["mediah"], name=record["name"]
+                        )
+                    )
+                    continue
+                c.good_news(
+                    "["
+                    + self.target
+                    + "]>[intelx.io] Fetching "
+                    + record["name"]
+                    + " as file "
+                    + filename
+                    + " ("
+                    + "{:,.0f}".format(record["size"] / float(1 << 20))
+                    + " MB)"
+                )
+                intelx.FILE_READ(record["systemid"], 0, record["bucket"], filename)
+                found_list = local_search([filename], [self.target])
+                for f in found_list:
+                    self.pwned += 1
+                    self.data.append(
+                        (
+                            "INTELX.IO",
+                            "{name} | Line: {line} - {content}".format(
+                                name=record["name"].strip(),
+                                line=f.line,
+                                content=" ".join(f.content.split()),
+                            ),
+                        )
+                    )
+                # print(contents) # Contains search data
+            for file in intel_files:
+                try:
+                    if self.debug:
+                        c.info_news(
+                            "["
+                            + self.target
+                            + f"]>[intelx.io] [DEBUG] Keeping {file}"
+                        )
+                    else:
+                        c.info_news(
+                            "["
+                            + self.target
+                            + f"]>[intelx.io] Removing {file}"
+                        )
+                        remove(file)
+                except Exception as ex:
+                    c.bad_news("intelx.io cleanup error: " + self.target)
+                    print(ex)
+
+        except Exception as ex:
+            c.bad_news("intelx.io error: " + self.target)
+            print(ex)
+
     def get_emailrepio(self, api_key=""):
         try:
             sleep(0.5)
@@ -300,7 +284,7 @@ class target:
                 c.info_news("[" + self.target + "]>[emailrep.io+key]")
             else:
                 c.info_news("[" + self.target + "]>[emailrep.io]")
-            url = "https://emailrep.io/{}".format(self.target)
+            url = f"https://emailrep.io/{self.target}"
             response = self.make_request(url)
             if response.status_code not in [200, 404, 429]:
                 c.bad_news("Could not contact emailrep for " + self.target)
@@ -314,7 +298,7 @@ class target:
                 )
             elif response.status_code == 404:
                 c.info_news(
-                    "No data found for {} using emailrep.io".format(self.target)
+                    f"No data found for {self.target} using emailrep.io"
                 )
             elif response.status_code == 200:
                 data = response.json()
@@ -335,7 +319,7 @@ class target:
                         self.data.append(
                             (
                                 "EMAILREP_LEAKS",
-                                "{} leaked credential".format(data["references"]),
+                                f"{data['references']} leaked credential",
                             )
                         )
                     else:
@@ -386,22 +370,22 @@ class target:
 
     def get_scylla(self, user_query="email"):
         try:
-            c.info_news("[" + self.target + "]>[scylla.sh]")
+            c.info_news("[" + self.target + "]>[scylla.so]")
             sleep(0.5)
             self.headers.update({"Accept": "application/json"})
             if user_query == "email":
-                uri_scylla = 'Email: "' + self.target + '"'
+                uri_scylla = 'email: "' + self.target + '"'
             elif user_query == "password":
-                uri_scylla = 'Password: "' + self.target + '"'
+                uri_scylla = 'password: "' + self.target + '"'
             elif user_query == "username":
-                uri_scylla = 'User: "' + self.target + '"'
+                uri_scylla = 'name: "' + self.target + '"'
             elif user_query == "ip":
-                uri_scylla = 'IP: "' + self.target + '"'
+                uri_scylla = 'ip: "' + self.target + '"'
             elif user_query == "hash":
-                uri_scylla = 'Hash: "' + self.target + '"'
+                uri_scylla = 'passhash: "' + self.target + '"'
             elif user_query == "domain":
-                uri_scylla = 'Email: "*@' + self.target + '"'
-            url = "https://scylla.sh/search?q={}".format(
+                uri_scylla = 'email: "*@' + self.target + '"'
+            url = "https://scylla.so/search?q={}".format(
                 requests.utils.requote_uri(uri_scylla)
             )
 
@@ -409,60 +393,62 @@ class target:
             response = self.make_request(
                 url,
                 verify=False,
-                auth=requests.auth.HTTPBasicAuth("sammy", "BasicPassword!"),
+                # auth=requests.auth.HTTPBasicAuth("sammy", "BasicPassword!"),
             )
             self.headers.popitem()
 
             if response.status_code not in [200, 404]:
-                c.bad_news("Could not contact scylla.sh for " + self.target)
+                c.bad_news("Could not contact scylla.so for " + self.target)
                 print(response.status_code)
                 print(response)
                 return
             data = response.json()
             total = 0
             for d in data:
-                for field, k in d["_source"].items():
+                for field, k in d["fields"].items():
                     if k is not None:
                         total += 1
             c.good_news(
-                "Found {num} entries for {target} using scylla.sh ".format(
+                "Found {num} entries for {target} using scylla.so ".format(
                     num=total, target=self.target
                 )
             )
             for d in data:
-                for field, k in d["_source"].items():
-                    if "User" in field and k is not None:
+                for field, k in d["fields"].items():
+                    if "name" in field and k is not None:
                         self.data.append(("SCYLLA_USERNAME", k))
                         self.pwned += 1
                     elif (
-                        "Email" in field and k is not None and user_query is not "email"
+                        "email" in field and k is not None and user_query != "email"
                     ):
                         self.data.append(("SCYLLA_EMAIL", k))
                         self.pwned += 1
-                    elif "Password" in field and k is not None:
+                    elif "password" in field and k is not None:
                         self.data.append(("SCYLLA_PASSWORD", k))
                         self.pwned += 1
-                    elif "PassHash" in field and k is not None:
+                    elif "passhash" in field and k is not None:
                         self.data.append(("SCYLLA_HASH", k))
                         self.pwned += 1
-                    elif "PassSalt" in field and k is not None:
+                    elif "passsalt" in field and k is not None:
                         self.data.append(("SCYLLA_HASHSALT", k))
                         self.pwned += 1
-                    elif "IP" in field and k is not None:
+                    elif "ip" in field and k is not None:
                         self.data.append(("SCYLLA_LASTIP", k))
                         self.pwned += 1
-                    elif "Domain" in field and k is not None:
+                    if "domain" in field and k is not None:
                         self.data.append(("SCYLLA_SOURCE", k))
                         self.pwned += 1
+                    else:
+                        self.data.append(("SCYLLA_SOURCE", "N/A"))
         except Exception as ex:
-            c.bad_news("scylla.sh error: " + self.target)
+            c.bad_news("scylla.so error: " + self.target)
             print(ex)
 
     def get_hunterio_public(self):
         try:
             c.info_news("[" + self.target + "]>[hunter.io public]")
             target_domain = self.target.split("@")[1]
-            url = "https://api.hunter.io/v2/email-count?domain={}".format(target_domain)
+            url = f"https://api.hunter.io/v2/email-count?domain={target_domain}"
             req = self.make_request(url)
             response = req.json()
             if response["data"]["total"] != 0:
@@ -473,23 +459,21 @@ class target:
                 )
             )
         except Exception as ex:
-            c.bad_news("hunter.io (pubic API) error: " + self.target)
+            c.bad_news("hunter.io (public API) error: " + self.target)
             print(ex)
 
     def get_hunterio_private(self, api_key):
         try:
             c.info_news("[" + self.target + "]>[hunter.io private]")
             target_domain = self.target.split("@")[1]
-            url = "https://api.hunter.io/v2/domain-search?domain={target}&api_key={key}".format(
-                target=target_domain, key=api_key
-            )
+            url = f"https://api.hunter.io/v2/domain-search?domain={target_domain}&api_key={api_key}"
             req = self.make_request(url)
             response = req.json()
             b_counter = 0
             for e in response["data"]["emails"]:
                 self.data.append(("HUNTER_RELATED", e["value"]))
                 b_counter += 1
-                if self.pwned is not 0:
+                if self.pwned != 0:
                     self.pwned += 1
             c.good_news(
                 "Found {num} related emails for {target} using hunter.io (private)".format(
@@ -498,7 +482,7 @@ class target:
             )
         except Exception as ex:
             c.bad_news(
-                "hunter.io (private API) error for {target}:".format(target=self.target)
+                f"hunter.io (private API) error for {self.target}:"
             )
             print(ex)
 
@@ -506,55 +490,63 @@ class target:
         try:
             if user_query == "ip":
                 user_query = "lastip"
-            if user_query in ["domain"]:
-                c.bad_news(
-                    "Snusbase does not support {} search (yet)".format(user_query)
-                )
-                return
+            if user_query == "domain":
+                payload = {"type": "email", "term": "%@" + self.target, "wildcard": "true"}
+            # elif user_query == "hash": If we want hash to search for password instead of reverse searching emails from the hash
+            #     payload = {"hash": self.target}
+            #     api_url = "https://api.snusbase.com/v3/hash"
+            else:
+                payload = {"type": user_query, "term": self.target}
             c.info_news("[" + self.target + "]>[snusbase]")
             url = api_url
-            self.headers.update({"Authorization": api_key})
-            payload = {"type": user_query, "term": self.target}
+            self.headers.update({"authorization": api_key})
+            # payload = {"type": user_query, "term": self.target}
             req = self.make_request(url, meth="POST", data=payload)
             self.headers.popitem()
             response = req.json()
-            c.good_news(
-                "Found {num} entries for {target} using Snusbase".format(
-                    num=len(response["result"]), target=self.target
+            if "error" in response:
+                c.bad_news("[snusbase]> " + response["error"])
+                c.bad_news("[snusbase]> " +  response["reason"])
+                return 1
+            if "size" in response:
+                c.good_news(
+                    "Found {num} entries for {target} using Snusbase".format(
+                        num=response["size"], target=self.target
+                    )
                 )
-            )
-            for result in response["result"]:
-                if result["email"] and self.not_exists(result["email"]):
-                    self.data.append(("SNUS_RELATED", result["email"].strip()))
-                if result["username"]:
-                    self.data.append(("SNUS_USERNAME", result["username"]))
-                    self.pwned += 1
-                if result["password"]:
-                    self.data.append(("SNUS_PASSWORD", result["password"]))
-                    self.pwned += 1
-                if result["hash"]:
-                    if result["salt"]:
-                        self.data.append(
-                            (
-                                "SNUS_HASH_SALT",
-                                result["hash"].strip() + " : " + result["salt"].strip(),
+                for result in response["results"]:
+                    if "email" in result and self.not_exists(result["email"]):
+                        self.data.append(("SNUS_RELATED", result["email"].strip()))
+                    if "username" in result:
+                        self.data.append(("SNUS_USERNAME", result["username"]))
+                        self.pwned += 1
+                    if "password" in result:
+                        self.data.append(("SNUS_PASSWORD", result["password"]))
+                        self.pwned += 1
+                    if "hash" in result:
+                        if "salt" in result:
+                            self.data.append(
+                                (
+                                    "SNUS_HASH_SALT",
+                                    result["hash"].strip() + " : " + result["salt"].strip(),
+                                )
                             )
-                        )
+                            self.pwned += 1
+                        else:
+                            self.data.append(("SNUS_HASH", result["hash"]))
+                            self.pwned += 1
+                    if "lastip" in result:
+                        self.data.append(("SNUS_LASTIP", result["lastip"]))
                         self.pwned += 1
+                    if "name" in result:
+                        self.data.append(("SNUS_NAME", result["name"]))
+                        self.pwned += 1
+                    if "db" in result and self.not_exists(result["db"]):
+                        self.data.append(("SNUS_SOURCE", result["db"]))
                     else:
-                        self.data.append(("SNUS_HASH", result["hash"]))
-                        self.pwned += 1
-                if result["lastip"]:
-                    self.data.append(("SNUS_LASTIP", result["lastip"]))
-                    self.pwned += 1
-                if result["name"]:
-                    self.data.append(("SNUS_NAME", result["name"]))
-                    self.pwned += 1
-                if result["tablenr"] and self.not_exists(result["tablenr"]):
-                    self.data.append(("SNUS_SOURCE", result["tablenr"]))
-
+                        self.data.append(("SNUS_SOURCE", "N/A"))
         except Exception as ex:
-            c.bad_news("Snusbase error with {target}".format(target=self.target))
+            c.bad_news(f"Snusbase error with {self.target}")
             print(ex)
 
     def get_leaklookup_pub(self, api_key):
@@ -575,14 +567,12 @@ class target:
                     self.data.append(("LEAKLOOKUP_PUB", result))
             if "false" in response["error"] and len(response["message"]) == 0:
                 c.info_news(
-                    "No breaches found for {} using Leak-lookup (public)".format(
-                        self.target
-                    )
+                    f"No breaches found for {self.target} using Leak-lookup (public)"
                 )
 
         except Exception as ex:
             c.bad_news(
-                "Leak-lookup error with {target} (public)".format(target=self.target)
+                f"Leak-lookup error with {self.target} (public)"
             )
             print(ex)
 
@@ -592,7 +582,7 @@ class target:
                 user_query = "ipadress"
             if user_query in ["hash"]:
                 c.bad_news(
-                    "Leaklookup does not support {} search (yet)".format(user_query)
+                    f"Leaklookup does not support {user_query} search (yet)"
                 )
                 return
             c.info_news("[" + self.target + "]>[leaklookup private]")
@@ -663,13 +653,11 @@ class target:
 
             if "false" in response["error"] and len(response["message"]) == 0:
                 c.info_news(
-                    "No breaches found for {} using Leak-lookup (private)".format(
-                        self.target
-                    )
+                    f"No breaches found for {self.target} using Leak-lookup (private)"
                 )
         except Exception as ex:
             c.bad_news(
-                "Leak-lookup error with {target} (private)".format(target=self.target)
+                f"Leak-lookup error with {self.target} (private)"
             )
             print(ex)
 
@@ -697,9 +685,7 @@ class target:
             if req.status_code == 200:
                 if response["Success"] is False:
                     c.bad_news(
-                        "WeLeakInfo (private) error response {}".format(
-                            response["Message"]
-                        )
+                        f"WeLeakInfo (private) error response {response['Message']}"
                     )
                     return
                 c.good_news(
@@ -723,9 +709,11 @@ class target:
                         self.pwned += 1
                     if "Database" in result and self.not_exists(result["Database"]):
                         self.data.append(("WLI_SOURCE", result["Database"]))
+                    else:
+                        self.data.append(("WLI_SOURCE", "N/A"))
         except Exception as ex:
             c.bad_news(
-                "WeLeakInfo error with {target} (private)".format(target=self.target)
+                f"WeLeakInfo error with {self.target} (private)"
             )
             print(ex)
 
@@ -758,17 +746,12 @@ class target:
                     self.data.append(("WLI_PUB_SRC", name + " (" + str(data) + ")"))
         except Exception as ex:
             c.bad_news(
-                "WeLeakInfo error with {target} (public)".format(target=self.target)
+                f"WeLeakInfo error with {self.target} (public)"
             )
             print(ex)
 
     def get_dehashed(self, api_email, api_key, user_query):
         try:
-            # New Dehashed API needs fixing, waiting for devs to respond
-            c.bad_news("Dehashed is temporarily unavailable")
-            c.bad_news("This should be fixed in the next updated\n")
-            return
-
             if user_query == "hash":
                 user_query == "hashed_password"
             if user_query == "ip":
@@ -831,12 +814,17 @@ class target:
                                 ("DHASHD_ID", result[tag] + " (type: " + tag + ")")
                             )
                             self.pwned += 1
-
+                    # Documentation and JSON are not synced, using both source keys
                     if "obtained_from" in result and self.not_exists(
                         result["obtained_from"]
                     ):
                         self.data.append(("DHASHD_SOURCE", result["obtained_from"]))
-
+                    elif "database_name" in result and self.not_exists(
+                        result["database_name"]
+                    ):
+                        self.data.append(("DHASHD_SOURCE", result["database_name"]))
+                    else:
+                        self.data.append(("DHASHD_SOURCE", "N/A"))
                 if response["balance"] is not None:
                     self.data.append(
                         (
@@ -845,8 +833,68 @@ class target:
                         )
                     )
             else:
-                c.bad_news("Dehashed error: status code " + req.status_code)
+                c.bad_news("Dehashed error: status code " + str(req.status_code))
             self.headers.popitem()
         except Exception as ex:
-            c.bad_news("Dehashed error with {target}".format(target=self.target))
+            c.bad_news(f"Dehashed error with {self.target}")
+            print(ex)
+    
+    def get_breachdirectory(self, user, passw, user_query):
+        # Todo: implement password source search when email has answer
+        c.info_news("[" + self.target + "]>[breachdirectory.org]")
+        if user_query not in ["email", "username", "password", "domain"]:
+            c.bad_news("Breachdirectory does not support this option")
+            exit(1)
+        mode = "pastes"
+        url = "https://breachdirectory.org/api/index?username={user}&password={passw}&func={mode}&term={target}".format(user=user, passw=passw, mode=mode, target=self.target)
+        try:
+            req = self.make_request(
+                    url, timeout=60
+                )
+            if req.status_code == 200:
+                    response = req.json()
+                    if response["data"] is not None:
+                        for result in response["data"]:
+                            if "email" in result and "email" not in user_query:
+                                self.data.append(("BREACHDR_EMAIL", result["email"]))
+                            if "password" in result:
+                                self.data.append(("BREACHDR_PASS", result["password"]))
+                            if "hash" in result:
+                                self.data.append(("BREACHDR_HASH", result["hash"]))
+                            if "source" in result:
+                                self.data.append(("BREACHDR_SOURCE", result["source"]))
+                                self.pwned += 1
+                            else:
+                                self.data.append(("BREACHDR_SOURCE", "N/A"))
+                    # Follow up with an aggregated leak sources query
+                    url_src = "https://breachdirectory.org/api/index?username={user}&password={passw}&func={mode}&term={target}".format(user=user, passw=passw, mode="sources", target=self.target)
+                    req = self.make_request(
+                        url_src, timeout=60
+                    )
+                    if req.status_code == 200:
+                        response = req.json()
+                        if response["sources"] is not None:
+                            for result in response["sources"]:
+                                self.data.append(("BREACHDR_EXTSRC", result))
+                    ## If using the 'auto' mode instead of pastes
+                    #     c.good_news(
+                    #         "Found {num} entries for {target} using breachdirectory.org".format(
+                    #             num=str(response["found"]), target=self.target
+                    #         )
+                    #     )
+
+                    # for result in response["result"]:
+                    #     if result["has_password"] is True:
+                    #         self.data.append(("BREACHDR_PASS", result["password"]))
+                    #         self.data.append(("BREACHDR_MD5", result["md5"]))
+                    #         if result["sources"] == "Unverified":
+                    #             source = result["sources"]
+                    #         elif len(result["sources"]) > 1:
+                    #             source = ", ".join(result["sources"])
+                    #         else:
+                    #             source = result["sources"][0]
+                    #         self.data.append(("BREACHDR_SOURCE", source))
+                    #         self.pwned += 1
+        except Exception as ex:
+            c.bad_news(f"Breachdirectory error with {self.target}")
             print(ex)
