@@ -20,6 +20,10 @@ def gen_config_file():
 ;emailrep = 
 ;dehashed_email = 
 ;dehashed_key =
+;intelx_key =
+;intelx_maxfile = 10
+;breachdirectory_user = 
+;breachdirectory_pass =
 """
         dest_config.write(config)
         c.good_news(
